otcextensions.sdk.cbr.v3.policy
===============================

.. automodule:: otcextensions.sdk.cbr.v3.policy

The CBR Policy Class
--------------------

The ``Policy`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.cbr.v3.policy.Policy
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.policy.Vault
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.policy.Trigger
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.policy.Properties
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.policy.OperationDefinition
   :members:
